# Python DWARF Parser

## Description

This is a Python module to parse DWARF debugging information found in compiled object files.

This code was originally part of Gregory Clayton's  `gsym` Python [project](https://github.com/YtnbFirewings/gsym)

## File Descriptions

List of files and their descriptions to go here.


## Credits

**Original Author:** Gregory Clayton \<gclayton@fb.com\>
